import React, { Component } from 'react';
import { TextLinkProps } from '@contentful/f36-text-link';
import { CommonProps } from '@contentful/f36-core';

interface NotificationCta {
    label: string;
    textLinkProps: Partial<TextLinkProps>;
}
declare type NotificationVariant = 'positive' | 'negative' | 'warning' | 'primary';

declare type Placement = 'top' | 'bottom';
interface NotificationProps {
    id: string | number;
    text: string;
    onClose: Function;
    duration?: number;
    withClose: boolean;
    isShown: boolean;
    variant: NotificationVariant;
    title?: string;
    cta?: Partial<NotificationCta>;
}
declare type ShowAction<T> = (text: string, setting?: {
    variant: NotificationVariant;
    id?: string;
    duration?: number;
    withClose?: boolean;
    title?: string;
    cta?: Partial<NotificationCta>;
}) => T;
declare type CloseAction<T> = (id: string | number) => T;
declare type CloseAllAction<T> = () => T;
declare type SetDurationAction<T> = (duration: number) => T;
declare type SetPlacementAction<T> = (placement: Placement, params?: {
    offset: number;
}) => T;
interface NotificationsManagerProps {
    register: (name: string, callback: Function) => void;
}
declare const NotificationsManager: {
    ({ register, }: NotificationsManagerProps): React.ReactElement;
    displayName: string;
};

interface NotificationsAPI {
    success: ShowAction<Notification>;
    error: ShowAction<Notification>;
    show: ShowAction<Notification>;
    close: CloseAction<void>;
    closeAll: CloseAllAction<void>;
    setPlacement: SetPlacementAction<void>;
    setDuration: SetDurationAction<void>;
}
declare type ExternalShowAction<T> = (text: string, settings?: {
    duration?: number;
    withClose?: boolean;
    id?: string;
    title?: string;
    cta?: Partial<NotificationCta>;
}) => T;
declare const Notification: {
    success: ExternalShowAction<Promise<NotificationProps>>;
    error: ExternalShowAction<Promise<NotificationProps>>;
    warning: ExternalShowAction<Promise<NotificationProps>>;
    info: ExternalShowAction<Promise<NotificationProps>>;
    close: CloseAction<Promise<void>>;
    closeAll: CloseAllAction<Promise<void>>;
    setPlacement: SetPlacementAction<Promise<void>>;
    setDuration: SetDurationAction<Promise<void>>;
};

interface NotificationItemProps extends CommonProps {
    /**
     * Defines the styling of notification
     * @default positive
     */
    variant?: NotificationVariant;
    /**
     * Defines if the close button should be rendered
     * @default true
     */
    withCloseButton?: boolean;
    /**
     * Aria label for close button
     * @default 'Dismiss'
     */
    closeButtonAriaLabel?: string;
    /**
     * Function that will be triggered when close button is clicked
     */
    onClose?: Function;
    /**
     * Title of the notification
     */
    title?: string;
    /**
     * Content of the notification
     */
    children: React.ReactNode;
    /**
     * Label and text-link props of the CTA
     */
    cta?: Partial<NotificationCta>;
}
declare const NotificationItem: React.ForwardRefExoticComponent<NotificationItemProps & React.RefAttributes<unknown>>;

interface NotificationItemContainerProps extends NotificationItemProps {
    duration?: number;
    isShown?: boolean;
}
interface NotificationItemContainerState {
    isShown: boolean;
}
declare class NotificationItemContainer extends Component<NotificationItemContainerProps, NotificationItemContainerState> {
    static defaultProps: Partial<NotificationItemContainerProps>;
    displayName: 'NotificationItemContainer';
    timer: number | null;
    state: {
        isShown: boolean;
    };
    componentDidMount(): void;
    componentDidUpdate(prevProps: NotificationItemContainerProps): void;
    componentWillUnmount(): void;
    startTimer: () => void;
    stopTimer: () => void;
    handleClose: () => void;
    handleMouseEnter: () => void;
    handleMouseLeave: () => void;
    render(): JSX.Element;
}

export { Notification, NotificationItem, NotificationItemContainer, NotificationItemContainerProps, NotificationItemProps, NotificationProps, NotificationVariant, NotificationsAPI, NotificationsManager, NotificationsManagerProps };
